# NiceDroplets

![](./media/ndlogo.svg)

A collection of helpful extensions for [NiceGUI](https://nicegui.io/).

[![PyPI](https://img.shields.io/pypi/v/nicegui?color=dark-green)](https://pypi.org/project/nicegui/)
[![Python versions](https://img.shields.io/badge/python-3.12%20|%203.13-blue.svg)](https://www.python.org/downloads/release/python-3106/)

## Placeholder

This is a placeholder project, which will be filled with useful extensions to the NiceGUI framework.

## Installation

```bash
pip install nice-droplets
```
